# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class KernelResourceSpecUpdateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'experiment_enabled': 'bool',
        'name': 'str',
        'priority': 'int',
        'workspace_enabled': 'bool'
    }

    attribute_map = {
        'description': 'description',
        'experiment_enabled': 'experiment_enabled',
        'name': 'name',
        'priority': 'priority',
        'workspace_enabled': 'workspace_enabled'
    }

    def __init__(self, description=None, experiment_enabled=None, name=None, priority=None, workspace_enabled=None, local_vars_configuration=None):  # noqa: E501
        """KernelResourceSpecUpdateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._experiment_enabled = None
        self._name = None
        self._priority = None
        self._workspace_enabled = None
        self.discriminator = None

        self.description = description
        if experiment_enabled is not None:
            self.experiment_enabled = experiment_enabled
        self.name = name
        self.priority = priority
        if workspace_enabled is not None:
            self.workspace_enabled = workspace_enabled

    @property
    def description(self):
        """Gets the description of this KernelResourceSpecUpdateAPIInput.  # noqa: E501


        :return: The description of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this KernelResourceSpecUpdateAPIInput.


        :param description: The description of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501

        self._description = description

    @property
    def experiment_enabled(self):
        """Gets the experiment_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501


        :return: The experiment_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :rtype: bool
        """
        return self._experiment_enabled

    @experiment_enabled.setter
    def experiment_enabled(self, experiment_enabled):
        """Sets the experiment_enabled of this KernelResourceSpecUpdateAPIInput.


        :param experiment_enabled: The experiment_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :type experiment_enabled: bool
        """

        self._experiment_enabled = experiment_enabled

    @property
    def name(self):
        """Gets the name of this KernelResourceSpecUpdateAPIInput.  # noqa: E501


        :return: The name of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this KernelResourceSpecUpdateAPIInput.


        :param name: The name of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def priority(self):
        """Gets the priority of this KernelResourceSpecUpdateAPIInput.  # noqa: E501


        :return: The priority of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this KernelResourceSpecUpdateAPIInput.


        :param priority: The priority of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :type priority: int
        """

        self._priority = priority

    @property
    def workspace_enabled(self):
        """Gets the workspace_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501


        :return: The workspace_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :rtype: bool
        """
        return self._workspace_enabled

    @workspace_enabled.setter
    def workspace_enabled(self, workspace_enabled):
        """Sets the workspace_enabled of this KernelResourceSpecUpdateAPIInput.


        :param workspace_enabled: The workspace_enabled of this KernelResourceSpecUpdateAPIInput.  # noqa: E501
        :type workspace_enabled: bool
        """

        self._workspace_enabled = workspace_enabled

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KernelResourceSpecUpdateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KernelResourceSpecUpdateAPIInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmAccessToken(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_dt': 'datetime',
        'edges': 'OrmAccessTokenEdges',
        'experiment_id': 'int',
        'expire_at': 'datetime',
        'id': 'int',
        'immutable_slug': 'str',
        'permissions': 'dict[str, object]',
        'pipeline_step_execution_id': 'int',
        'service_id': 'int',
        'title': 'str',
        'type': 'str',
        'updated_dt': 'datetime',
        'user_id': 'int',
        'workspace_id': 'int'
    }

    attribute_map = {
        'created_dt': 'created_dt',
        'edges': 'edges',
        'experiment_id': 'experiment_id',
        'expire_at': 'expire_at',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'permissions': 'permissions',
        'pipeline_step_execution_id': 'pipeline_step_execution_id',
        'service_id': 'service_id',
        'title': 'title',
        'type': 'type',
        'updated_dt': 'updated_dt',
        'user_id': 'user_id',
        'workspace_id': 'workspace_id'
    }

    def __init__(self, created_dt=None, edges=None, experiment_id=None, expire_at=None, id=None, immutable_slug=None, permissions=None, pipeline_step_execution_id=None, service_id=None, title=None, type=None, updated_dt=None, user_id=None, workspace_id=None, local_vars_configuration=None):  # noqa: E501
        """OrmAccessToken - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_dt = None
        self._edges = None
        self._experiment_id = None
        self._expire_at = None
        self._id = None
        self._immutable_slug = None
        self._permissions = None
        self._pipeline_step_execution_id = None
        self._service_id = None
        self._title = None
        self._type = None
        self._updated_dt = None
        self._user_id = None
        self._workspace_id = None
        self.discriminator = None

        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        self.experiment_id = experiment_id
        self.expire_at = expire_at
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if permissions is not None:
            self.permissions = permissions
        self.pipeline_step_execution_id = pipeline_step_execution_id
        self.service_id = service_id
        self.title = title
        if type is not None:
            self.type = type
        if updated_dt is not None:
            self.updated_dt = updated_dt
        self.user_id = user_id
        self.workspace_id = workspace_id

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmAccessToken.  # noqa: E501


        :return: The created_dt of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmAccessToken.


        :param created_dt: The created_dt of this OrmAccessToken.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmAccessToken.  # noqa: E501


        :return: The edges of this OrmAccessToken.  # noqa: E501
        :rtype: OrmAccessTokenEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmAccessToken.


        :param edges: The edges of this OrmAccessToken.  # noqa: E501
        :type edges: OrmAccessTokenEdges
        """

        self._edges = edges

    @property
    def experiment_id(self):
        """Gets the experiment_id of this OrmAccessToken.  # noqa: E501


        :return: The experiment_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._experiment_id

    @experiment_id.setter
    def experiment_id(self, experiment_id):
        """Sets the experiment_id of this OrmAccessToken.


        :param experiment_id: The experiment_id of this OrmAccessToken.  # noqa: E501
        :type experiment_id: int
        """

        self._experiment_id = experiment_id

    @property
    def expire_at(self):
        """Gets the expire_at of this OrmAccessToken.  # noqa: E501


        :return: The expire_at of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._expire_at

    @expire_at.setter
    def expire_at(self, expire_at):
        """Sets the expire_at of this OrmAccessToken.


        :param expire_at: The expire_at of this OrmAccessToken.  # noqa: E501
        :type expire_at: datetime
        """

        self._expire_at = expire_at

    @property
    def id(self):
        """Gets the id of this OrmAccessToken.  # noqa: E501


        :return: The id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmAccessToken.


        :param id: The id of this OrmAccessToken.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmAccessToken.  # noqa: E501


        :return: The immutable_slug of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmAccessToken.


        :param immutable_slug: The immutable_slug of this OrmAccessToken.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def permissions(self):
        """Gets the permissions of this OrmAccessToken.  # noqa: E501


        :return: The permissions of this OrmAccessToken.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this OrmAccessToken.


        :param permissions: The permissions of this OrmAccessToken.  # noqa: E501
        :type permissions: dict[str, object]
        """

        self._permissions = permissions

    @property
    def pipeline_step_execution_id(self):
        """Gets the pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501


        :return: The pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._pipeline_step_execution_id

    @pipeline_step_execution_id.setter
    def pipeline_step_execution_id(self, pipeline_step_execution_id):
        """Sets the pipeline_step_execution_id of this OrmAccessToken.


        :param pipeline_step_execution_id: The pipeline_step_execution_id of this OrmAccessToken.  # noqa: E501
        :type pipeline_step_execution_id: int
        """

        self._pipeline_step_execution_id = pipeline_step_execution_id

    @property
    def service_id(self):
        """Gets the service_id of this OrmAccessToken.  # noqa: E501


        :return: The service_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._service_id

    @service_id.setter
    def service_id(self, service_id):
        """Sets the service_id of this OrmAccessToken.


        :param service_id: The service_id of this OrmAccessToken.  # noqa: E501
        :type service_id: int
        """

        self._service_id = service_id

    @property
    def title(self):
        """Gets the title of this OrmAccessToken.  # noqa: E501


        :return: The title of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this OrmAccessToken.


        :param title: The title of this OrmAccessToken.  # noqa: E501
        :type title: str
        """

        self._title = title

    @property
    def type(self):
        """Gets the type of this OrmAccessToken.  # noqa: E501


        :return: The type of this OrmAccessToken.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmAccessToken.


        :param type: The type of this OrmAccessToken.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmAccessToken.  # noqa: E501


        :return: The updated_dt of this OrmAccessToken.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmAccessToken.


        :param updated_dt: The updated_dt of this OrmAccessToken.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def user_id(self):
        """Gets the user_id of this OrmAccessToken.  # noqa: E501


        :return: The user_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this OrmAccessToken.


        :param user_id: The user_id of this OrmAccessToken.  # noqa: E501
        :type user_id: int
        """

        self._user_id = user_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this OrmAccessToken.  # noqa: E501


        :return: The workspace_id of this OrmAccessToken.  # noqa: E501
        :rtype: int
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this OrmAccessToken.


        :param workspace_id: The workspace_id of this OrmAccessToken.  # noqa: E501
        :type workspace_id: int
        """

        self._workspace_id = workspace_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmAccessToken):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmAccessToken):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseKernelClusterUsageInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cpu_device_hours': 'float',
        'cpu_limit': 'float',
        'created_by': 'ResponseSimpleUser',
        'created_dt': 'datetime',
        'experiment': 'ResponseSimpleExperiment',
        'gpu_device_hours': 'float',
        'gpu_limit': 'int',
        'gpu_type': 'str',
        'memory_limit': 'str',
        'organization': 'ResponseOrganization',
        'pipeline_step_execution': 'ResponseReducedPipelineStepExecution',
        'project': 'ResponseSimpleProject',
        'resource_type': 'str',
        'service': 'ResponseSimpleServiceInfo',
        'status': 'str',
        'workload_type': 'str',
        'workspace': 'ResponseSimpleWorkspace'
    }

    attribute_map = {
        'cpu_device_hours': 'cpu_device_hours',
        'cpu_limit': 'cpu_limit',
        'created_by': 'created_by',
        'created_dt': 'created_dt',
        'experiment': 'experiment',
        'gpu_device_hours': 'gpu_device_hours',
        'gpu_limit': 'gpu_limit',
        'gpu_type': 'gpu_type',
        'memory_limit': 'memory_limit',
        'organization': 'organization',
        'pipeline_step_execution': 'pipeline_step_execution',
        'project': 'project',
        'resource_type': 'resource_type',
        'service': 'service',
        'status': 'status',
        'workload_type': 'workload_type',
        'workspace': 'workspace'
    }

    def __init__(self, cpu_device_hours=None, cpu_limit=None, created_by=None, created_dt=None, experiment=None, gpu_device_hours=None, gpu_limit=None, gpu_type=None, memory_limit=None, organization=None, pipeline_step_execution=None, project=None, resource_type=None, service=None, status=None, workload_type=None, workspace=None, local_vars_configuration=None):  # noqa: E501
        """ResponseKernelClusterUsageInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cpu_device_hours = None
        self._cpu_limit = None
        self._created_by = None
        self._created_dt = None
        self._experiment = None
        self._gpu_device_hours = None
        self._gpu_limit = None
        self._gpu_type = None
        self._memory_limit = None
        self._organization = None
        self._pipeline_step_execution = None
        self._project = None
        self._resource_type = None
        self._service = None
        self._status = None
        self._workload_type = None
        self._workspace = None
        self.discriminator = None

        if cpu_device_hours is not None:
            self.cpu_device_hours = cpu_device_hours
        self.cpu_limit = cpu_limit
        self.created_by = created_by
        self.created_dt = created_dt
        if experiment is not None:
            self.experiment = experiment
        if gpu_device_hours is not None:
            self.gpu_device_hours = gpu_device_hours
        self.gpu_limit = gpu_limit
        self.gpu_type = gpu_type
        self.memory_limit = memory_limit
        self.organization = organization
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        self.project = project
        self.resource_type = resource_type
        if service is not None:
            self.service = service
        self.status = status
        self.workload_type = workload_type
        if workspace is not None:
            self.workspace = workspace

    @property
    def cpu_device_hours(self):
        """Gets the cpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The cpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: float
        """
        return self._cpu_device_hours

    @cpu_device_hours.setter
    def cpu_device_hours(self, cpu_device_hours):
        """Sets the cpu_device_hours of this ResponseKernelClusterUsageInfo.


        :param cpu_device_hours: The cpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type cpu_device_hours: float
        """

        self._cpu_device_hours = cpu_device_hours

    @property
    def cpu_limit(self):
        """Gets the cpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The cpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: float
        """
        return self._cpu_limit

    @cpu_limit.setter
    def cpu_limit(self, cpu_limit):
        """Sets the cpu_limit of this ResponseKernelClusterUsageInfo.


        :param cpu_limit: The cpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type cpu_limit: float
        """

        self._cpu_limit = cpu_limit

    @property
    def created_by(self):
        """Gets the created_by of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The created_by of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseSimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ResponseKernelClusterUsageInfo.


        :param created_by: The created_by of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type created_by: ResponseSimpleUser
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def created_dt(self):
        """Gets the created_dt of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The created_dt of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ResponseKernelClusterUsageInfo.


        :param created_dt: The created_dt of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def experiment(self):
        """Gets the experiment of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The experiment of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseSimpleExperiment
        """
        return self._experiment

    @experiment.setter
    def experiment(self, experiment):
        """Sets the experiment of this ResponseKernelClusterUsageInfo.


        :param experiment: The experiment of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type experiment: ResponseSimpleExperiment
        """

        self._experiment = experiment

    @property
    def gpu_device_hours(self):
        """Gets the gpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The gpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: float
        """
        return self._gpu_device_hours

    @gpu_device_hours.setter
    def gpu_device_hours(self, gpu_device_hours):
        """Sets the gpu_device_hours of this ResponseKernelClusterUsageInfo.


        :param gpu_device_hours: The gpu_device_hours of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type gpu_device_hours: float
        """

        self._gpu_device_hours = gpu_device_hours

    @property
    def gpu_limit(self):
        """Gets the gpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The gpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: int
        """
        return self._gpu_limit

    @gpu_limit.setter
    def gpu_limit(self, gpu_limit):
        """Sets the gpu_limit of this ResponseKernelClusterUsageInfo.


        :param gpu_limit: The gpu_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type gpu_limit: int
        """

        self._gpu_limit = gpu_limit

    @property
    def gpu_type(self):
        """Gets the gpu_type of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The gpu_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._gpu_type

    @gpu_type.setter
    def gpu_type(self, gpu_type):
        """Sets the gpu_type of this ResponseKernelClusterUsageInfo.


        :param gpu_type: The gpu_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type gpu_type: str
        """

        self._gpu_type = gpu_type

    @property
    def memory_limit(self):
        """Gets the memory_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The memory_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._memory_limit

    @memory_limit.setter
    def memory_limit(self, memory_limit):
        """Sets the memory_limit of this ResponseKernelClusterUsageInfo.


        :param memory_limit: The memory_limit of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type memory_limit: str
        """

        self._memory_limit = memory_limit

    @property
    def organization(self):
        """Gets the organization of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The organization of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this ResponseKernelClusterUsageInfo.


        :param organization: The organization of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type organization: ResponseOrganization
        """
        if self.local_vars_configuration.client_side_validation and organization is None:  # noqa: E501
            raise ValueError("Invalid value for `organization`, must not be `None`")  # noqa: E501

        self._organization = organization

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The pipeline_step_execution of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseReducedPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this ResponseKernelClusterUsageInfo.


        :param pipeline_step_execution: The pipeline_step_execution of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type pipeline_step_execution: ResponseReducedPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def project(self):
        """Gets the project of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The project of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseSimpleProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this ResponseKernelClusterUsageInfo.


        :param project: The project of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type project: ResponseSimpleProject
        """
        if self.local_vars_configuration.client_side_validation and project is None:  # noqa: E501
            raise ValueError("Invalid value for `project`, must not be `None`")  # noqa: E501

        self._project = project

    @property
    def resource_type(self):
        """Gets the resource_type of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The resource_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ResponseKernelClusterUsageInfo.


        :param resource_type: The resource_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type resource_type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501

        self._resource_type = resource_type

    @property
    def service(self):
        """Gets the service of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The service of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseSimpleServiceInfo
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this ResponseKernelClusterUsageInfo.


        :param service: The service of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type service: ResponseSimpleServiceInfo
        """

        self._service = service

    @property
    def status(self):
        """Gets the status of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The status of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ResponseKernelClusterUsageInfo.


        :param status: The status of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def workload_type(self):
        """Gets the workload_type of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The workload_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._workload_type

    @workload_type.setter
    def workload_type(self, workload_type):
        """Sets the workload_type of this ResponseKernelClusterUsageInfo.


        :param workload_type: The workload_type of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type workload_type: str
        """
        if self.local_vars_configuration.client_side_validation and workload_type is None:  # noqa: E501
            raise ValueError("Invalid value for `workload_type`, must not be `None`")  # noqa: E501

        self._workload_type = workload_type

    @property
    def workspace(self):
        """Gets the workspace of this ResponseKernelClusterUsageInfo.  # noqa: E501


        :return: The workspace of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :rtype: ResponseSimpleWorkspace
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this ResponseKernelClusterUsageInfo.


        :param workspace: The workspace of this ResponseKernelClusterUsageInfo.  # noqa: E501
        :type workspace: ResponseSimpleWorkspace
        """

        self._workspace = workspace

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseKernelClusterUsageInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseKernelClusterUsageInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseWorkloadEndpoints(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'manually_defined_endpoints': 'list[OrmWorkloadEndpoint]',
        'ssh': 'OrmWorkloadEndpoint',
        'web_terminal': 'OrmWorkloadEndpoint',
        'web_terminal_attach': 'OrmWorkloadEndpoint'
    }

    attribute_map = {
        'manually_defined_endpoints': 'manually_defined_endpoints',
        'ssh': 'ssh',
        'web_terminal': 'web_terminal',
        'web_terminal_attach': 'web_terminal_attach'
    }

    def __init__(self, manually_defined_endpoints=None, ssh=None, web_terminal=None, web_terminal_attach=None, local_vars_configuration=None):  # noqa: E501
        """ResponseWorkloadEndpoints - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._manually_defined_endpoints = None
        self._ssh = None
        self._web_terminal = None
        self._web_terminal_attach = None
        self.discriminator = None

        if manually_defined_endpoints is not None:
            self.manually_defined_endpoints = manually_defined_endpoints
        if ssh is not None:
            self.ssh = ssh
        if web_terminal is not None:
            self.web_terminal = web_terminal
        if web_terminal_attach is not None:
            self.web_terminal_attach = web_terminal_attach

    @property
    def manually_defined_endpoints(self):
        """Gets the manually_defined_endpoints of this ResponseWorkloadEndpoints.  # noqa: E501


        :return: The manually_defined_endpoints of this ResponseWorkloadEndpoints.  # noqa: E501
        :rtype: list[OrmWorkloadEndpoint]
        """
        return self._manually_defined_endpoints

    @manually_defined_endpoints.setter
    def manually_defined_endpoints(self, manually_defined_endpoints):
        """Sets the manually_defined_endpoints of this ResponseWorkloadEndpoints.


        :param manually_defined_endpoints: The manually_defined_endpoints of this ResponseWorkloadEndpoints.  # noqa: E501
        :type manually_defined_endpoints: list[OrmWorkloadEndpoint]
        """

        self._manually_defined_endpoints = manually_defined_endpoints

    @property
    def ssh(self):
        """Gets the ssh of this ResponseWorkloadEndpoints.  # noqa: E501


        :return: The ssh of this ResponseWorkloadEndpoints.  # noqa: E501
        :rtype: OrmWorkloadEndpoint
        """
        return self._ssh

    @ssh.setter
    def ssh(self, ssh):
        """Sets the ssh of this ResponseWorkloadEndpoints.


        :param ssh: The ssh of this ResponseWorkloadEndpoints.  # noqa: E501
        :type ssh: OrmWorkloadEndpoint
        """

        self._ssh = ssh

    @property
    def web_terminal(self):
        """Gets the web_terminal of this ResponseWorkloadEndpoints.  # noqa: E501


        :return: The web_terminal of this ResponseWorkloadEndpoints.  # noqa: E501
        :rtype: OrmWorkloadEndpoint
        """
        return self._web_terminal

    @web_terminal.setter
    def web_terminal(self, web_terminal):
        """Sets the web_terminal of this ResponseWorkloadEndpoints.


        :param web_terminal: The web_terminal of this ResponseWorkloadEndpoints.  # noqa: E501
        :type web_terminal: OrmWorkloadEndpoint
        """

        self._web_terminal = web_terminal

    @property
    def web_terminal_attach(self):
        """Gets the web_terminal_attach of this ResponseWorkloadEndpoints.  # noqa: E501


        :return: The web_terminal_attach of this ResponseWorkloadEndpoints.  # noqa: E501
        :rtype: OrmWorkloadEndpoint
        """
        return self._web_terminal_attach

    @web_terminal_attach.setter
    def web_terminal_attach(self, web_terminal_attach):
        """Sets the web_terminal_attach of this ResponseWorkloadEndpoints.


        :param web_terminal_attach: The web_terminal_attach of this ResponseWorkloadEndpoints.  # noqa: E501
        :type web_terminal_attach: OrmWorkloadEndpoint
        """

        self._web_terminal_attach = web_terminal_attach

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWorkloadEndpoints):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseWorkloadEndpoints):
            return True

        return self.to_dict() != other.to_dict()



import inspect
import os

import pytest
from mock import Mock, patch

import vessl
from openapi_client.api import APIV1Api
from openapi_client.models import SignInAPIInput, SignInCliConfirmAPIInput
from vessl.util.config import VesslConfigLoader
from vessl.util.exception import VesslApiException

USE_MOCK = not os.environ.get("VESSL_TEST_MOCK_OFF", False)

TEST_CLUSTER_NAME = "aws-uw2-dev"
TEST_IMAGE_NAME = "vessl/kernels:py36.full-cpu"
TEST_RESOURCE_NAME = "v1.cpu-0.mem-1"

vessl.EXEC_MODE = "TEST"
PROJECT_ROOT = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
TEST_CONFIG_PATH = f"{PROJECT_ROOT}/test/config"


def pytest_sessionstart(session):
    vessl.vessl_api.config_loader = VesslConfigLoader(TEST_CONFIG_PATH)

    if USE_MOCK:
        vessl.vessl_api.organization = Mock()
        vessl.vessl_api.organization.name = "test-org"
        vessl.vessl_api.project = Mock()
        vessl.vessl_api.project.name = "project"
        patch_api_calls()

    else:
        vessl.vessl_api.api_client.configuration.host = os.environ.get(
            "VESSL_API_HOST", "http://localhost:10000"
        )
        setup_test_account()


def pytest_sessionfinish(session, exitstatus):
    try:
        os.remove(TEST_CONFIG_PATH)
    except OSError:
        pass


def generate_patch_fixture(name, return_value):
    @pytest.fixture(scope="session", autouse=True)
    def func():
        with patch(name, return_value=return_value) as _fixture:
            yield _fixture

    return func


def patch_api_calls():
    for name, value in inspect.getmembers(APIV1Api, predicate=inspect.isfunction):
        if name.endswith("api"):
            patch_name = f"vessl.vessl_api.{name}"
            globals()[name] = generate_patch_fixture(patch_name, Mock())


def setup_test_account():
    name = "test-name"
    username = "test-username"
    password = "test-password"
    email = "test@email.com"

    # Setup user
    try:
        jwt_token = vessl.vessl_api.sign_in_api(
            sign_in_api_input=SignInAPIInput(
                email_or_username=email,
                password=password,
            )
        ).token
    except VesslApiException:
        # jwt_token = vessl.vessl_api.sign_up_pending_user_api(
        #     sign_up_api_input=SignUpPendingUserAPIInput(
        #         name=name,
        #         username=username,
        #         password=password,
        #         email=email,
        #     )
        # ).token
        pass

    # Configure access token
    cli_token = vessl.vessl_api.sign_in_cli_token_api().cli_token
    vessl.vessl_api.api_client.set_default_header(
        "Authorization",
        f"JWT {jwt_token}",
    )
    vessl.vessl_api.sign_in_cli_confirm_api(
        sign_in_cli_confirm_api_input=SignInCliConfirmAPIInput(
            cli_token=cli_token,
        )
    )
    access_token = vessl.vessl_api.sign_in_cli_check_api(cli_token=cli_token).access_token
    vessl.configure_access_token(access_token=access_token)

    # Configure organization
    organization_name = "test-org"
    organizations = vessl.list_organizations()
    if organization_name not in {x.name for x in organizations}:
        vessl.create_organization(
            organization_name=organization_name,
        )
    vessl.configure_organization(organization_name=organization_name)

    # Configure project
    project_name = "test-project"
    projects = vessl.list_projects()
    if project_name not in {x.name for x in projects}:
        vessl.create_project(
            project_name=project_name,
        )
    vessl.configure_project(project_name=project_name)



import shutil
from test.conftest import USE_MOCK

import pytest

import vessl
from vessl.util.exception import VesslApiException
from vessl.util.random import random_string


@pytest.mark.skipif(USE_MOCK, reason="Does not run if mocking is used.")
class TestDataset:
    dataset_name = random_string()

    @classmethod
    def teardown_class(cls):
        shutil.rmtree("test/fixture/tmp/", ignore_errors=True)

    @pytest.mark.order(index=1)
    def test_create_dataset(self):
        vessl.create_dataset(
            dataset_name=self.dataset_name,
            description=random_string(),
        )

    @pytest.mark.order(index=2)
    def test_upload_dataset_volume_file(self):
        vessl.upload_dataset_volume_file(self.dataset_name, "test/fixture/file1.txt", "file1.txt")
        vessl.upload_dataset_volume_file(
            self.dataset_name,
            "test/fixture/folder1",
            "folder1",
        )

    def test_read_dataset(self):
        vessl.read_dataset(self.dataset_name)

    def test_list_datasets(self):
        vessl.list_datasets()

    def test_list_dataset_volume_files(self):
        vessl.list_dataset_volume_files(self.dataset_name)

    def test_download_dataset_volume_file(self):
        vessl.download_dataset_volume_file(
            self.dataset_name, "file1.txt", "test/fixture/tmp/file2.txt"
        )
        vessl.download_dataset_volume_file(
            self.dataset_name,
            "folder1",
            "test/fixture/tmp/folder1",
        )

    def test_copy_dataset_volume_file(self):
        vessl.copy_dataset_volume_file(self.dataset_name, "file1.txt", "file1_copy.txt")
        vessl.copy_dataset_volume_file(
            self.dataset_name,
            "folder1",
            "folder1_copy",
        )

    @pytest.mark.order(index=-1)
    def test_delete_dataset_volume_file(self):
        vessl.delete_dataset_volume_file(self.dataset_name, "file1.txt")
        vessl.delete_dataset_volume_file(self.dataset_name, "folder1")
        with pytest.raises(VesslApiException):
            vessl.delete_dataset_volume_file(self.dataset_name, "folder1")
